Module: ApiHammer

Defined in:
lib/api_hammer/halt.rb,
lib/api_hammer.rb,
lib/api_hammer/version.rb,
lib/api_hammer/weblink.rb,
lib/api_hammer/request_logger.rb,
lib/api_hammer/trailing_newline.rb,
lib/api_hammer/faraday/outputter.rb,
lib/api_hammer/show_text_exceptions.rb,
lib/api_hammer/rails_request_logging.rb,
lib/api_hammer/rails_request_logging.rb,
lib/api_hammer/faraday/request_logger.rb

Overview

the contents of this file are to let you halt a controller in its processing without having to have a return in the actual action. this lets helper methods which do things like parameter validation halt.

it is desgined to function similarly to Sinatra's handling of throw(:halt), but is based around exceptions because rails doesn't catch anything, just rescues.

Defined Under Namespace

Modules: Rails Classes: Faraday, FaradayCurlVOutputter, FaradayOutputter, Halt, RailsRequestLogging, RequestLogSubscriber, RequestLogger, ShowTextExceptions, TrailingNewline, Weblink

Constant Summary collapse

VERSION =
"0.4.3"